@@ -11,7 +11,7 @@ use namespace::clean;
 
 with 'Role::REST::Client';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 has api_url => (
     isa => Str,
@@ -39,6 +39,9 @@ has '_required_fields' => (
         sms => [qw(mocean-from mocean-to mocean-text)],
         'verify/req' => [qw(mocean-to mocean-brand)],
         'verify/check' => [qw(mocean-reqid mocean-code)],
+        'report/message' => [qw(mocean-msgid)],
+        'account/balance' => [],
+        'account/pricing' => [],
     }}
 );
 
@@ -58,27 +61,44 @@ sub BUILD {
 sub send_sms {
     my ($self, $params) = @_;
 
-    return $self->_request('sms', $params, undef, undef, 'post');
+    return $self->_request('sms', $params, 'post');
 }
 
 sub send_verification_code {
     my ($self, $params) = @_;
 
-    return $self->_request('verify/req', $params, undef, undef, 'post');
+    return $self->_request('verify/req', $params, 'post');
 }
 
 sub check_verification_code {
     my ($self, $params) = @_;
 
-    return $self->_request('verify/check', $params, undef, undef, 'post');
+    return $self->_request('verify/check', $params, 'post');
+}
+
+sub get_account_balance {
+    my ($self) = @_;
+
+    return $self->_request('account/balance', undef, 'get');
+}
+
+sub get_account_pricing {
+    my ($self) = @_;
+
+    return $self->_request('account/pricing', undef, 'get');
+}
+
+sub get_message_status {
+    my ($self, $params) = @_;
+
+    return $self->_request('report/message', $params, 'get');
 }
 
 sub _request {
-    my ($self, $command, $queries, $format, $method) = @_;
+    my ($self, $command, $queries, $method) = @_;
 
     $command ||= q||;
     $queries ||= {};
-    $format ||= 'xml';
     $method ||= 'get';
 
     $self->_check_required_params($command, $queries);
@@ -88,7 +108,10 @@ sub _request {
 
     # In case the api_url was updated.
     $self->server($self->api_url);
-    $self->type(qq|application/$format|);
+
+    my $response_format = $queries->{'mocean-resp-format'} || 'xml';
+
+    $self->type(qq|application/$response_format|);
 
     # Do not append '/' at the end of URL. Otherwise you will get HTTP 406
     # error.
@@ -239,6 +262,26 @@ Check the verfication code received from your user.
         'mocean-code' => '234839',
     });
 
+=head2 get_account_balance()
+
+Get your Mocean account balance.
+
+    my $response = $mocean_api->get_account_balance();
+
+=head2 get_account_pricing()
+
+Get your Mocean account pricing and supported destination.
+
+    my $response = $mocean_api->get_account_pricing();
+
+=head2 get_message_status()
+
+Get the outbound SMS current status.
+
+    my $response = $mocean_api->get_message_status({
+        'mocean-msgid' => 123456
+    });
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2018 by Kian Meng, Ang.
